==> swarmauri_tool_jupyterexportmarkdown-1.1.0.dev10.tar.gz: swarmauri_tool_jupyterexportmarkdown-1.1.0.dev10/README.md <==
<!-- 
 _______  _     _  _______  ______    __   __  _______  __   __  ______    ___  
|       || | _ | ||   _   ||    _ |  |  |_|  ||   _   ||  | |  ||    _ |  |   | 
|  _____|| || || ||  |_|  ||   | ||  |       ||  |_|  ||  | |  ||   | ||  |   | 
| |_____ |       ||       ||   |_||_ |       ||       ||  |_|  ||   |_||_ |   | 
|_____  ||       ||       ||    __  ||       ||       ||       ||    __  ||   | 
 _____| ||   _   ||   _   ||   |  | || ||_|| ||   _   ||       ||   |  | ||   | 
|_______||__| |__||__| |__||___|  |_||_|   |_||__| |__||_______||___|  |_||___| 

                                                   
Swarmauri Tools for reading Jupyter Notebook files using nbformat
-->

<p align="center">
    <a href="https://pypi.org/project/swarmauri_tool_jupyterexportmarkdown/">
        <img src="https://img.shields.io/pypi/dm/swarmauri_tool_jupyterexportmarkdown" alt="PyPI - Downloads"/></a>
    <a href="https://github.com/swarmauri/swarmauri-sdk/pkgs/community/swarmauri_tool_jupyterexportmarkdown">
        <img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/swarmauri/swarmauri-sdk/pkgs/community/swarmauri_tool_jupyterexportmarkdown&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false" alt="GitHub Hits"/></a>
    <a href="https://pypi.org/project/swarmauri/swarmauri_tool_jupyterexportmarkdown">
        <img src="https://img.shields.io/pypi/pyversions/swarmauri_tool_jupyterexportmarkdown" alt="PyPI - Python Version"/></a>
    <a href="https://pypi.org/project/swarmauri/swarmauri_tool_jupyterexportmarkdown">
        <img src="https://img.shields.io/pypi/l/swarmauri_tool_jupyterexportmarkdown" alt="PyPI - License"/></a>
    <br />
    <a href="https://pypi.org/project/swarmauri/swarmauri_tool_jupyterexportmarkdown">
        <img src="https://img.shields.io/pypi/v/swarmauri_tool_jupyterexportmarkdown?label=swarmauri_tool_jupyterexportmarkdown&color=green" alt="PyPI - swarmauri_tool_jupyterexportmarkdown"/></a>
</p>

---

# swarmauri_tool_jupyterexportmarkdown

==> swarmauri_tool_jupyterexportmarkdown-1.1.2.dev3.tar.gz: swarmauri_tool_jupyterexportmarkdown-1.1.2.dev3/README.md <==
-<!-- 
 _______  _     _  _______  ______    __   __  _______  __   __  ______    ___  
|       || | _ | ||   _   ||    _ |  |  |_|  ||   _   ||  | |  ||    _ |  |   | 
|  _____|| || || ||  |_|  ||   | ||  |       ||  |_|  ||  | |  ||   | ||  |   | 
| |_____ |       ||       ||   |_||_ |       ||       ||  |_|  ||   |_||_ |   | 
|_____  ||       ||       ||    __  ||       ||       ||       ||    __  ||   | 
 _____| ||   _   ||   _   ||   |  | || ||_|| ||   _   ||       ||   |  | ||   | 
|_______||__| |__||__| |__||___|  |_||_|   |_||__| |__||_______||___|  |_||___| 
 
-                                                   
-Swarmauri Tools for reading Jupyter Notebook files using nbformat
--->



![Swamauri Logo](https://res.cloudinary.com/dbjmpekvl/image/upload/v1730099724/Swarmauri-logo-lockup-2048x757_hww01w.png)

<p align="center">
    <a href="https://pypi.org/project/swarmauri_tool_jupyterexportmarkdown/">
        <img src="https://img.shields.io/pypi/dm/swarmauri_tool_jupyterexportmarkdown" alt="PyPI - Downloads"/></a>
    <a href="https://github.com/swarmauri/swarmauri-sdk/blob/master/pkgs/community/swarmauri_tool_jupyterexportmarkdown/README.md">
        <img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https://github.com/swarmauri/swarmauri-sdk/pkgs/community/swarmauri_tool_jupyterexportmarkdown/README.md&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=hits&edge_flat=false" alt="GitHub Hits"/></a>
    <a href="https://pypi.org/project/swarmauri_tool_jupyterexportmarkdown/">
        <img src="https://img.shields.io/pypi/pyversions/swarmauri_tool_jupyterexportmarkdown" alt="PyPI - Python Version"/></a>
    <a href="https://pypi.org/project/swarmauri_tool_jupyterexportmarkdown/">
        <img src="https://img.shields.io/pypi/l/swarmauri_tool_jupyterexportmarkdown" alt="PyPI - License"/></a>
    <a href="https://pypi.org/project/swarmauri_tool_jupyterexportmarkdown/">
        <img src="https://img.shields.io/pypi/v/swarmauri_tool_jupyterexportmarkdown?label=swarmauri_tool_jupyterexportmarkdown&color=green" alt="PyPI - swarmauri_tool_jupyterexportmarkdown"/></a>
</p>

---

# swarmauri_tool_jupyterexportmarkdown
